@@ -1,5 +1,5 @@
 /* enckdcreppart.c --- Key distribution encrypted reply part functions
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -375,7 +375,7 @@ shishi_enckdcreppart_server_set (Shishi * handle,
 {
   char *tmpserver;
   char **serverbuf;
-  char *tokptr;
+  char *tokptr = NULL;
   int res;
   int i;
 
