@@ -1,5 +1,5 @@
 /* init.c --- Initialization functions.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -22,6 +22,9 @@
 
 #include "internal.h"
 
+/* Get gl_sockets_startup. */
+#include "sockets.h"
+
 /* Get _shishi_tls_init. */
 #include "starttls.h"
 
@@ -49,6 +52,14 @@ init_handle (int outputtype)
       return NULL;
     }
 
+  rc = gl_sockets_startup (SOCKETS_2_1);
+  if (rc)
+    {
+      shishi_warn (handle, "Failed to initialized Windows sockets (%d)", rc);
+      free (handle);
+      return NULL;
+    }
+
   rc = _shishi_crypto_init (handle);
   if (rc != SHISHI_OK)
     {
