@@ -30,6 +30,48 @@
 # include <stringprep.h>
 #endif
 
+/**
+ * shishi_prompt_password_callback_set:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @cb: function pointer to application password callback, a
+ *   #shishi_prompt_password_func type.
+ *
+ * Set a callback function that will be used by
+ * shishi_prompt_password() to query the user for a password.  The
+ * function pointer can be retrieved using
+ * shishi_prompt_password_callback_get().
+ *
+ * The @cb function should follow the %shishi_prompt_password_func prototype:
+ *
+ * int prompt_password (Shishi * @handle, char **@s,
+ * const char *@format, va_list @ap);
+ *
+ * If the function returns 0, the @s variable should contain a newly
+ * allocated string with the password read from the user.
+ **/
+void
+shishi_prompt_password_callback_set (Shishi * handle,
+				     shishi_prompt_password_func cb)
+{
+  handle->prompt_passwd = cb;
+}
+
+/**
+ * shishi_prompt_password_callback_get:
+ * @handle: shishi handle as allocated by shishi_init().
+ *
+ * Get the application password prompt function callback as set by
+ * shishi_prompt_password_callback_set().
+ *
+ * Returns: Returns the callback, a #shishi_prompt_password_func type,
+ *   or %NULL.
+ **/
+shishi_prompt_password_func
+shishi_prompt_password_callback_get (Shishi * handle)
+{
+  return handle->prompt_passwd;
+}
+
 /**
  * shishi_prompt_password:
  * @handle: shishi handle as allocated by shishi_init().
@@ -50,6 +92,16 @@ shishi_prompt_password (Shishi * handle, char **s, const char *format, ...)
   char *p;
   va_list ap;
 
+  if (handle->prompt_passwd)
+    {
+      int ret;
+      va_start (ap, format);
+      ret = handle->prompt_passwd (handle, s, format, ap);
+      va_end (ap);
+
+      return ret;
+    }
+
 #ifdef HAVE_LIBIDN
   if (VERBOSE (handle))
     {
