@@ -34,15 +34,16 @@
 #include <unistd.h>
 
 /* Get gethostbyname, getservbyname. */
-#ifdef HAVE_NETDB_H
-# include <netdb.h>
-#endif
+#include <netdb.h>
 
 /* Get getpwnam. */
 #ifdef HAVE_PWD_H
 # include <pwd.h>
 #endif
 
+/* For errno. */
+#include <errno.h>
+
 /* For select, etc. */
 #include <sys/types.h>
 
@@ -65,14 +66,6 @@
 # include <sys/ioctl.h>
 #endif
 
-/* Get errno. */
-#ifdef HAVE_ERRNO_H
-# include <errno.h>
-#endif
-#ifndef errno
-extern int errno;
-#endif
-
 /* Get signal, etc. */
 #include <signal.h>
 
