@@ -1,5 +1,5 @@
 /* shishi.c --- Shishi command line interface.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -62,13 +62,9 @@ usage (int status)
   else
     {
       cmdline_parser_print_help ();
-      /* TRANSLATORS: The placeholder indicates the bug-reporting address
-	 for this package.  Please add _another line_ saying
-	 "Report translation bugs to <...>\n" with the address for translation
-	 bugs (typically your translation team's web or email address).  */
       printf (_("\nMandatory arguments to long options are "
-		"mandatory for short options too.\n\nReport bugs to <%s>.\n"),
-	      PACKAGE_BUGREPORT);
+		"mandatory for short options too.\n"));
+      emit_bug_reporting_address ();
     }
   exit (status);
 }
@@ -91,7 +87,10 @@ main (int argc, char *argv[])
 
   if (args.version_given)
     {
-      version_etc (stdout, "shishi", PACKAGE_NAME, VERSION,
+      const char *p = PACKAGE_NAME;
+      if (strcmp (shishi_check_version (NULL), PACKAGE_VERSION) != 0)
+	p = PACKAGE_STRING;
+      version_etc (stdout, program_name, p, shishi_check_version (NULL),
 		   "Simon Josefsson", (char *) NULL);
       return EXIT_SUCCESS;
     }
