@@ -315,8 +315,8 @@ doit (void)
   kdc_listen ();
 
   {
-    char *slash = strrchr (program_name, '/');
-    char *shortname = (slash != NULL ? slash + 1 : program_name);
+    const char *slash = strrchr (program_name, '/');
+    const char *shortname = (slash != NULL ? slash + 1 : program_name);
 
 #ifdef LOG_PERROR
     openlog (shortname, LOG_CONS | LOG_PERROR, LOG_DAEMON);
@@ -483,6 +483,9 @@ const char version_etc_copyright[] =
      year.  */
   "Copyright %s %d Simon Josefsson.";
 
+static void
+usage (int status) __attribute__ ((__noreturn__));
+
 static void
 usage (int status)
 {
