@@ -1,5 +1,5 @@
 /* key.c --- Shishi KEY self tests.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -26,7 +26,7 @@ void
 test (Shishi * handle)
 {
   Shishi_key *key;
-  char *p;
+  const char *p;
   int res;
 
   res = shishi_key_from_base64 (handle,
