@@ -20,62 +20,22 @@
  *
  */
 
-#if HAVE_CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
-#include <ctype.h>
-#include <stdint.h>
-#include <sys/types.h>
-#include <sys/select.h>
-#include <sys/socket.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/time.h>
-#include <time.h>
 
-#ifdef HAVE_NETDB_H
-#include <netdb.h>
-#endif
-
-#if defined HAVE_DECL_H_ERRNO && !HAVE_DECL_H_ERRNO
-/* extern int h_errno; */
-#endif
-
-#ifdef HAVE_PWD_H
-#include <pwd.h>
-#endif
-
-#ifdef HAVE_SYS_IOCTL_H
-#include <sys/ioctl.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
-#include <signal.h>
-
-#include <netinet/in.h>
-#ifdef HAVE_NETINET_IN6_H
-#include <netinet/in6.h>
-#endif
-
-#include "base64.h"
-
-#include <shishi.h>
+#include "utils.h"
 
 const char *program_name = PACKAGE;
 
-static int verbose = 0;
-static int debug = 0;
-static int error_count = 0;
-static int break_on_error = 0;
+int debug = 0;
+int error_count = 0;
+int break_on_error = 0;
 
-static void
+void
 fail (const char *format, ...)
 {
   va_list arg_ptr;
@@ -88,85 +48,79 @@ fail (const char *format, ...)
     exit (1);
 }
 
-static void
+void
 success (const char *format, ...)
 {
   va_list arg_ptr;
 
   va_start (arg_ptr, format);
-  if (verbose)
+  if (debug)
     vfprintf (stdout, format, arg_ptr);
   va_end (arg_ptr);
 }
 
-static void
-escapeprint (const char *str, int len)
+void
+escapeprint (const char *str, size_t len)
 {
-  int i;
+  size_t i;
 
-  if (!str || !len)
-    return;
-
-  printf ("\t ;; `");
-  for (i = 0; i < len; i++)
-    if ((str[i] >= 'A' && str[i] <= 'Z') ||
-	(str[i] >= 'a' && str[i] <= 'z') ||
-	(str[i] >= '0' && str[i] <= '9') || str[i] == '.')
-      printf ("%c", str[i] & 0xFF);
-    else
-      printf ("\\x%02x", str[i] & 0xFF);
-  printf ("' (length %d bytes)\n", len);
-}
-
-static void
-hexprint (const char *str, int len)
-{
-  int i;
-
-  if (!str || !len)
-    return;
-
-  printf ("\t ;; ");
+  printf (" (length %d bytes):\n\t", len);
   for (i = 0; i < len; i++)
     {
-      printf ("%02x ", str[i] & 0xFF);
+      if (((str[i] & 0xFF) >= 'A' && (str[i] & 0xFF) <= 'Z') ||
+	  ((str[i] & 0xFF) >= 'a' && (str[i] & 0xFF) <= 'z') ||
+	  ((str[i] & 0xFF) >= '0' && (str[i] & 0xFF) <= '9')
+	  || (str[i] & 0xFF) == ' ' || (str[i] & 0xFF) == '.')
+	printf ("%c", (str[i] & 0xFF));
+      else
+	printf ("\\x%02X", (str[i] & 0xFF));
+      if ((i + 1) % 16 == 0 && (i + 1) < len)
+	printf ("'\n\t'");
+    }
+  printf ("\n");
+}
+
+void
+hexprint (const char *str, size_t len)
+{
+  size_t i;
+
+  printf ("\t;; ");
+  for (i = 0; i < len; i++)
+    {
+      printf ("%02x ", (str[i] & 0xFF));
       if ((i + 1) % 8 == 0)
 	printf (" ");
       if ((i + 1) % 16 == 0 && i + 1 < len)
-	printf ("\n\t ;; ");
+	printf ("\n\t;; ");
     }
-  puts ("");
+  printf ("\n");
 }
 
-static void
-binprint (const char *str, int len)
+void
+binprint (const char *str, size_t len)
 {
-  int i;
+  size_t i;
 
-  if (!str || !len)
-    return;
-
-  printf ("\t ;; ");
+  printf ("\t;; ");
   for (i = 0; i < len; i++)
     {
       printf ("%d%d%d%d%d%d%d%d ",
-	      str[i] & 0x80 ? 1 : 0,
-	      str[i] & 0x40 ? 1 : 0,
-	      str[i] & 0x20 ? 1 : 0,
-	      str[i] & 0x10 ? 1 : 0,
-	      str[i] & 0x08 ? 1 : 0,
-	      str[i] & 0x04 ? 1 : 0,
-	      str[i] & 0x02 ? 1 : 0, str[i] & 0x01 ? 1 : 0);
+	      (str[i] & 0xFF) & 0x80 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x40 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x20 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x10 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x08 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x04 ? 1 : 0,
+	      (str[i] & 0xFF) & 0x02 ? 1 : 0, (str[i] & 0xFF) & 0x01 ? 1 : 0);
       if ((i + 1) % 3 == 0)
 	printf (" ");
       if ((i + 1) % 6 == 0 && i + 1 < len)
-	printf ("\n\t ;; ");
+	printf ("\n\t;; ");
     }
-  puts ("");
+  printf ("\n");
 }
 
-void test (Shishi * handle);
-
 int
 main (int argc, char *argv[])
 {
@@ -175,9 +129,6 @@ main (int argc, char *argv[])
   do
     if (strcmp (argv[argc - 1], "-v") == 0 ||
 	strcmp (argv[argc - 1], "--verbose") == 0)
-      verbose = 1;
-    else if (strcmp (argv[argc - 1], "-d") == 0 ||
-	     strcmp (argv[argc - 1], "--debug") == 0)
       debug = 1;
     else if (strcmp (argv[argc - 1], "-b") == 0 ||
 	     strcmp (argv[argc - 1], "--break-on-error") == 0)
@@ -186,8 +137,8 @@ main (int argc, char *argv[])
 	     strcmp (argv[argc - 1], "-?") == 0 ||
 	     strcmp (argv[argc - 1], "--help") == 0)
       {
-	printf ("Usage: %s [-vdbh?] [--verbose] [--debug] "
-		"[--break-on-error] [--help]\n", argv[0]);
+	printf ("Usage: %s [-vbh?] [--verbose] [--break-on-error] [--help]\n",
+		argv[0]);
 	return 1;
       }
   while (argc-- > 1);
@@ -212,8 +163,8 @@ main (int argc, char *argv[])
 
   shishi_done (handle);
 
-  if (verbose)
-    printf ("Self test `%s' done with %d errors\n", argv[0], error_count);
+  if (debug)
+    printf ("Self test `%s' finished with %d errors\n", argv[0], error_count);
 
   return error_count ? 1 : 0;
 }
